==> isis-fish-4.2.0.1-sources.jar: fr/ifremer/isisfish/ui/input/variable/VariableTypeComboModel.java <==
/*
 * #%L
 * IsisFish
 * 
 * $Id: VariableTypeComboModel.java 3614 2012-02-20 12:12:45Z echatellier $
 * $HeadURL: http://svn.forge.codelutin.com/svn/isis-fish/tags/isis-fish-4.2.0.1/src/main/java/fr/ifremer/isisfish/ui/input/variable/VariableTypeComboModel.java $
 * %%
 * Copyright (C) 2012 Ifremer, CodeLutin, Chatellier Eric
 * %%
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as
 * published by the Free Software Foundation, either version 2 of the 
 * License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public 
 * License along with this program.  If not, see
 * <http://www.gnu.org/licenses/gpl-2.0.html>.
 * #L%
 */

package fr.ifremer.isisfish.ui.input.variable;

import java.util.ArrayList;
import java.util.List;

import javax.swing.DefaultComboBoxModel;

import fr.ifremer.isisfish.entities.VariableType;

/**
 * Modele pour la liste des type possible de variable.
 *
 * @author chatellier
 * @version $Revision: 3614 $
 * 
 * Last update : $Date: 2012-02-20 13:12:45 +0100 (Mon, 20 Feb 2012) $
 * By : $Author: echatellier $
 */
public class VariableTypeComboModel extends DefaultComboBoxModel {

    /** serialVersionUID. */
    private static final long serialVersionUID = 6171850179969290032L;

    /** Values list */
    protected VariableType[] variableTypes;

    /**
     * Empty constructor.
     */
    public VariableTypeComboModel() {
        variableTypes = VariableType.values();
    }

    /*
     * @see javax.swing.ListModel#getElementAt(int)
     */
    @Override
    public Object getElementAt(int index) {
        return variableTypes[index];
    }

    /*
     * @see javax.swing.ListModel#getSize()
     */
    @Override
    public int getSize() {
        int size = 0;

        if (variableTypes != null) {
            size = variableTypes.length;
        }
        return size;
    }
}

==> isis-fish-4.3.0.0-sources.jar: fr/ifremer/isisfish/ui/input/variable/VariableTypeComboModel.java <==
/*
 * #%L
 * IsisFish
 * 
 * $Id: VariableTypeComboModel.java 3969 2014-04-17 16:48:13Z echatellier $
 * $HeadURL: https://svn.codelutin.com/isis-fish/tags/isis-fish-4.3.0.0/src/main/java/fr/ifremer/isisfish/ui/input/variable/VariableTypeComboModel.java $
 * %%
 * Copyright (C) 2012 Ifremer, CodeLutin, Chatellier Eric
 * %%
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as
 * published by the Free Software Foundation, either version 3 of the 
 * License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public 
 * License along with this program.  If not, see
 * <http://www.gnu.org/licenses/gpl-3.0.html>.
 * #L%
 */

package fr.ifremer.isisfish.ui.input.variable;

import javax.swing.DefaultComboBoxModel;

import fr.ifremer.isisfish.entities.VariableType;

/**
 * Modele pour la liste des type possible de variable.
 *
 * @author chatellier
 * @version $Revision: 3969 $
 * 
 * Last update : $Date: 2014-04-17 18:48:13 +0200 (Thu, 17 Apr 2014) $
 * By : $Author: echatellier $
 */
public class VariableTypeComboModel extends DefaultComboBoxModel<VariableType> {

    /** serialVersionUID. */
    private static final long serialVersionUID = 6171850179969290032L;

    /** Values list */
    protected VariableType[] variableTypes;

    /**
     * Empty constructor.
     */
    public VariableTypeComboModel() {
        variableTypes = VariableType.values();
    }

    /*
     * @see javax.swing.ListModel#getElementAt(int)
     */
    @Override
    public VariableType getElementAt(int index) {
        return variableTypes[index];
    }

    /*
     * @see javax.swing.ListModel#getSize()
     */
    @Override
    public int getSize() {
        int size = 0;

        if (variableTypes != null) {
            size = variableTypes.length;
        }
        return size;
    }
}
